"use strict";

var _interopRequireWildcard = require("@babel/runtime-corejs2/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime-corejs2/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Init = void 0;

var _regenerator = _interopRequireDefault(require("@babel/runtime-corejs2/regenerator"));

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime-corejs2/helpers/asyncToGenerator"));

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime-corejs2/helpers/defineProperty"));

var _parseInt2 = _interopRequireDefault(require("@babel/runtime-corejs2/core-js/parse-int"));

var _chalk = _interopRequireDefault(require("chalk"));

var _path = _interopRequireDefault(require("path"));

var _rimraf = _interopRequireDefault(require("rimraf"));

var _ncp = require("ncp");

var _fs = _interopRequireWildcard(require("fs"));

var _inquirer = _interopRequireDefault(require("inquirer"));

var _jsYaml = require("js-yaml");

var _helps = require("./helps");

var _logger = require("../lib/utils/logger");

var _util = require("util");

var pncp = (0, _util.promisify)(_ncp.ncp);

var askQuestions = function askQuestions() {
  var questions = [{
    name: "NAME",
    type: "input",
    message: "What is the name of your first deck?",
    default: "deck"
  }, {
    type: "list",
    name: "SIZE",
    message: "What is your card size?",
    choices: ["Poker", "Bridge", "Other"]
  }, {
    type: "input",
    name: "WIDTH",
    message: "What is your card width?",
    default: "825",
    when: function when(res) {
      return res.SIZE === "Other";
    },
    filter: function filter(n) {
      return (0, _parseInt2.default)(n, 10);
    }
  }, {
    type: "input",
    name: "HEIGHT",
    message: "What is your card height?",
    default: "1125",
    when: function when(res) {
      return res.SIZE === "Other";
    },
    filter: function filter(n) {
      return (0, _parseInt2.default)(n, 10);
    }
  }, {
    type: "checkbox",
    name: "FORMATS",
    message: "What formats do you want to generate??",
    default: "svg",
    choices: [{
      name: "svg",
      checked: true
    }, "png", "pdf"]
  }];
  return _inquirer.default.prompt(questions);
};

var touchSync = function touchSync(filename) {
  return _fs.default.closeSync(_fs.default.openSync(filename, "w"));
};

var getDefaultSizes = function getDefaultSizes(size) {
  switch (size) {
    case "Bridge":
      return {
        width: 750,
        height: 1125
      };

    case "Poker":
    default:
      return {
        width: 825,
        height: 1125
      };
  }
};

var getConfig = function getConfig(_ref) {
  var NAME = _ref.NAME,
      SIZE = _ref.SIZE,
      WIDTH = _ref.WIDTH,
      HEIGHT = _ref.HEIGHT,
      FORMATS = _ref.FORMATS;
  var defaultSizes = getDefaultSizes(SIZE);
  return (0, _defineProperty2.default)({}, "".concat(NAME), {
    width: WIDTH ? WIDTH : defaultSizes.width,
    height: HEIGHT ? HEIGHT : defaultSizes.height,
    format: FORMATS
  });
};

var dirEmpty = function dirEmpty(path) {
  return !(0, _fs.existsSync)(path) || (0, _fs.existsSync)(path) && !_fs.default.readdirSync(path).length;
};

var Init =
/*#__PURE__*/
function () {
  var _ref3 = (0, _asyncToGenerator2.default)(
  /*#__PURE__*/
  _regenerator.default.mark(function _callee(args) {
    var examplePath, destDir, answers, configPath, cleanupPaths;
    return _regenerator.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            if (args.help) {
              (0, _helps.logInitHelp)();
            }

            examplePath = _path.default.join(__dirname, "..", "..", "..", "examples");
            destDir = _path.default.resolve(args.path);
            console.log(_chalk.default.green("Creating new deck in ".concat(destDir)));

            if (!dirEmpty(destDir)) {
              (0, _logger.printAndExit)(_chalk.default.red("There's already a file at ".concat(destDir, ".")));
            }

            _context.next = 7;
            return askQuestions();

          case 7:
            answers = _context.sent;
            _context.prev = 8;
            _context.next = 11;
            return pncp(examplePath, destDir);

          case 11:
            _context.next = 16;
            break;

          case 13:
            _context.prev = 13;
            _context.t0 = _context["catch"](8);
            (0, _logger.printAndExit)(_context.t0);

          case 16:
            configPath = _path.default.join(destDir, "deck.config.yml"); // Write config file

            _fs.default.writeFileSync(configPath, (0, _jsYaml.safeDump)(getConfig(answers))); // Rename example files


            _fs.default.renameSync(_path.default.join(destDir, "data", "example.csv"), _path.default.join(destDir, "data", "".concat(answers.NAME, ".csv")));

            _fs.default.renameSync(_path.default.join(destDir, "templates", "example.js"), _path.default.join(destDir, "templates", "".concat(answers.NAME, ".js"))); // Cleanup


            cleanupPaths = ["node_modules", "package-lock.json", "output"];
            cleanupPaths.forEach(function (p) {
              p = _path.default.join(destDir, p);

              if ((0, _fs.existsSync)(p)) {
                _rimraf.default.sync(p);
              }
            });
            (0, _logger.printAndExit)("\n    Your project is now set up and ready to go. To start, run the following commands:\n\n    $ cd ".concat(args.path, "\n    $ npm install\n    $ npm run build\n  "));

          case 23:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, this, [[8, 13]]);
  }));

  return function Init(_x) {
    return _ref3.apply(this, arguments);
  };
}();

exports.Init = Init;