"use strict";

var _interopRequireWildcard = require("@babel/runtime-corejs2/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime-corejs2/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Flexbox = void 0;

var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime-corejs2/helpers/objectWithoutProperties"));

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime-corejs2/helpers/objectSpread"));

var _parseFloat2 = _interopRequireDefault(require("@babel/runtime-corejs2/core-js/parse-float"));

var _react = _interopRequireDefault(require("react"));

var _yogaLayout = _interopRequireWildcard(require("yoga-layout"));

var _yoga = require("./lib/yoga");

var setNodePadding = function setNodePadding(val, dir) {
  var edge = (0, _yoga.getEdge)(dir);

  if (val) {
    if (val === "auto") {
      node.setPaddingAuto(edge);
    } else if (val.indexOf("%") !== -1) {
      node.setPaddingPercent(edge, (0, _parseFloat2.default)(val, 10));
    } else {
      node.setPadding(edge, val);
    }
  }
};

var setNodeMargin = function setNodeMargin(val, dir) {
  var edge = (0, _yoga.getEdge)(dir);

  if (val) {
    if (val === "auto") {
      node.setMarginAuto(edge);
    } else if (val.indexOf("%") !== -1) {
      node.setMarginPercent(edge, (0, _parseFloat2.default)(val, 10));
    } else {
      node.setMargin(edge, val);
    }
  }
};

var setStyles = function setStyles(node) {
  var style = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

  if (style.alignContent) {
    var alignContent = (0, _yoga.getAlign)(style.alignContent);
    node.setAlignContent(alignContent);
  }

  if (style.alignItems) {
    var alignItems = (0, _yoga.getAlign)(style.alignItems);
    node.setAlignItems(alignItems);
  }

  if (style.display) {
    var display = (0, _yoga.getDisplay)(style.display);
    node.setDisplay(display);
  }

  if (style.flexDirection) {
    var flexDirection = (0, _yoga.getFlexDirection)(style.flexDirection);
    node.setFlexDirection(flexDirection);
  }

  if (style.flexWrap) {
    var flexWrap = (0, _yoga.getFlexWrap)(style.flexWrap);
    node.setFlexWrap(flexWrap);
  }

  if (style.justifyContent) {
    var justifyContent = (0, _yoga.getJustifyContent)(style.justifyContent);
    node.setJustifyContent(justifyContent);
  }

  if (style.aspectRatio) {
    node.setAspectRatio(style.aspectRatio);
  }

  if (style.flex) {
    node.setFlex(style.flex);
  }

  if (style.flexGrow) {
    node.setFlexGrow(style.flexGrow);
  }

  if (style.flexShrink) {
    node.setFlexShrink(style.flexShrink);
  }

  if (style.flexBasis) {
    node.setFlexBasis(style.flexBasis);
  }

  if (style.flexBasisPercent) {
    node.setFlexBasisPercent(style.flexBasisPercent);
  } // Set Height


  if (style.minHeight) {
    node.setMinHeight(style.minHeight);
  }

  if (style.maxHeight) {
    node.setMaxHeight(style.maxHeight);
  }

  if (style.height) {
    node.setHeight(style.height);
  } else {
    node.setHeightAuto();
  } // Set Width


  if (style.minWidth) {
    node.setMinWidth(style.minWidth);
  }

  if (style.maxWidth) {
    node.setMaxWidth(style.maxWidth);
  }

  if (style.width) {
    node.setWidth(style.width);
  } else {
    node.setWidthAuto();
  } // Borders


  if (style.borderWidth) {
    node.setBorder((0, _yoga.getEdge)("all"), style.borderWidth);
  } // Margins


  setNodeMargin(style.marginTop, "top");
  setNodeMargin(style.marginRight, "right");
  setNodeMargin(style.marginBottom, "bottom");
  setNodeMargin(style.marginleft, "left");

  if (style.margin) {
    node.setMargin((0, _yoga.getEdge)("all"), style.margin);
  } // Padding


  setNodePadding(style.paddingTop, "top");
  setNodePadding(style.paddingRight, "right");
  setNodePadding(style.paddingBottom, "bottom");
  setNodePadding(style.paddingleft, "left");

  if (style.padding) {
    node.setPadding((0, _yoga.getEdge)("all"), style.padding);
  }

  return node;
};

var mergeStyles = function mergeStyles(_ref) {
  var style = _ref.style,
      width = _ref.width,
      height = _ref.height,
      strokeWidth = _ref.strokeWidth;
  return (0, _objectSpread2.default)({}, style, {
    width: width,
    height: height,
    borderWidth: strokeWidth
  });
};

var Flexbox = function Flexbox(_ref2) {
  var children = _ref2.children,
      props = (0, _objectWithoutProperties2.default)(_ref2, ["children"]);

  // Create Root Node
  var root = _yogaLayout.Node.create();

  var rootStyle = mergeStyles(props);
  root = setStyles(root, rootStyle); // Create Child Nodes & Add Styles

  _react.default.Children.forEach(children, function (c, i) {
    var child = _yogaLayout.Node.create();

    var style = mergeStyles(c.props);
    child = setStyles(child, style);
    root.insertChild(child, i);
    return child;
  }); // Calculate the Layout


  root.calculateLayout(rootStyle.width, rootStyle.height, _yogaLayout.default.DIRECTION_LTR);
  var rootLayout = root.getComputedLayout(); // Clone Children with new Layout props

  var newChildren = _react.default.Children.map(children, function (c, i) {
    var childNode = root.getChild(i);
    var layout = childNode.getComputedLayout();
    return _react.default.cloneElement(c, {
      width: layout.width,
      height: layout.height,
      transform: "translate(".concat(layout.left, " ").concat(layout.top, ")")
    });
  }); // Return new group with layout applied


  return _react.default.createElement("g", {
    width: rootLayout.width,
    height: rootLayout.height,
    transform: "translate(".concat(rootLayout.left, " ").concat(rootLayout.top, ")")
  }, newChildren);
};

exports.Flexbox = Flexbox;